NodeObject

Type Alias NodeObject 

pub type NodeObject<TState> = dyn DynNode<TState> + Send + Sync;
Type alias for trait objects

This alias simplifies working with dynamic node collections in workflows. Use this when you need to store different node types in the same collection.