DynTask

Trait DynTask 

pub trait DynTask<TState>: Task<TState, MemoryStore, DefaultTaskParams>
where TState: Clone + Debug + Send + Sync + 'static,
{ }
Concrete task trait object with default types

This trait provides a concrete implementation of Task using the default types, enabling dynamic dispatch and trait object usage.

Implementors

Source

impl<TState, T> DynTask<TState> for T
where TState: Clone + Debug + Send + Sync + 'static, T: Task<TState, MemoryStore, DefaultTaskParams>,